; Modified from Nick Bensema's playfield code by 
; Randall Gordon (DarkOrk) / DarkOrk@digicron.com / UIN: 1695704
; Nick's Site: http://www.primenet.com/~nickb/atariprg.htm
; Thanks for the great code Nick
; For more info about all the instructions used in this program
; get his source code.  I just commented the parts I changed
; and added.
;
;	Description 
;
;    Draws a playfield using the method in Nick Bensema's code.  If
;    the button on the joystick is pressed then the playfield isn't
;    drawn but instead the background color is changed.  When the
;    button is released the playfield is drawn again.  When the
;    joystick is moved; left, right, up, or down is displayed on the
;    screen.
;
;	Notes
;
;    Some (most? :)) of the techniques I use in this programs could
;    be majorly improved.  I just wrote this to get a firm grip on
;    how to get input from the joystick.  A few things could be
;    changed in the drawing of the playfield.  Perhaps a pointer to
;    the playfield data to use instead of branching to a routine
;    that does each.

	processor 6502
	include vcs.h

	org $F000

OnOff	= $80
BGColor	= $90
Right	= $A0
Left	= $B0
Down	= $C0
Up	= $D0

START
	SEI
	CLD
	LDX  #$FF
	TXS
	LDA #0
B1      STA 0,X
	DEX
	BNE B1

;Init stuff
	LDA #0
	STA OnOff
	STA BGColor
	STA Right
	STA Left
	STA Down
	STA Up
	LDA #$2A
	STA COLUPF

MainLoop
	JSR  VB
	JSR  CheckJoyStick
	JSR  DrawScreen
	JSR  OverScan
	JMP  MainLoop

VB ;Vertical Blanking
	LDA  #2
	STA  WSYNC  
	STA  WSYNC
	STA  WSYNC
	STA  VSYNC
	STA  WSYNC
	STA  WSYNC
	LDA  #44
	STA  TIM64T
	LDA  #0
	STA  CXCLR
	STA  WSYNC
	STA  VSYNC

	RTS  

CheckJoyStick
	LDA  #0		; Load 0 into A
	STA  OnOff	; Load A (0) into OnOff (The playfield will be drawn)
	STA  Right	; Load A (0) into Right (No movement is known yet)
	STA  Left	; Load A (0) into Left (No movement is known yet)
	STA  Down	; Load A (0) into Down (No movement is known yet)
	STA  Up		; Load A (0) into Up (No movement is known yet)
	LDX  INPT4		; Load the INPT4 register into X
	BPL  ButtonPressed	; Check and see if the button is pressed
	JMP  CheckStick
	RTS

ButtonPressed
	DEC  BGColor	;Subtract 1 from the current background value
	LDA  BGColor	;Load the current background value into A
	STA  COLUBK	;Store background value in the background register
	LDA  #$FF	;Set OnOff to #$FF
	STA  OnOff	;OnOff will be #$FF so the playfield isn't drawn
	RTS

DrawScreen
	LDA INTIM
	BNE DrawScreen
	STA WSYNC
	STA VBLANK
	LDA #0
	STA CTRLPF
	LDY #191

ScanLoop
	STA WSYNC
	TYA
	AND #7
	TAX
	LDA OnOff	;Load OnOff into A
	CMP #$FF	;Check and see if we shouldn't draw the playfield
	BEQ SkipDraw	;If OnOff is #$FF then we skip drawing the playfield
	LDA Right
	CMP #$FF	;Check if right is "on"
	BEQ DrawR
	LDA Left
	CMP #$FF	;Check if left is "on"
	BEQ DrawL
	LDA Down
	CMP #$FF	;Check if down is "on"
	BEQ DrawD
	LDA Up
	CMP #$FF	;Check if up is "on"
	BEQ DrawU
	LDA PFData0,X
	STA WSYNC
	STA PF0
	LDA PFData1,X
	STA PF1
	LDA PFData2,X
	STA PF2
ReEnter
	DEY
	BNE ScanLoop

	LDA #2
	STA WSYNC
	STA VBLANK
	STY PF0
	STY PF1
	STY PF2
	RTS

SkipDraw
	LDA #0
	STA PF0	;Clear PF0
	STA PF1	;Clear PF0
	STA PF2	;Clear PF0
	JMP ReEnter

DrawR
	LDA PFDataR0,X
	STA WSYNC
	STA PF0
	LDA PFDataR1,X
	STA PF1
	LDA PFDataR2,X
	STA PF2
	JMP ReEnter

DrawL
	LDA PFDataL0,X
	STA WSYNC
	STA PF0
	LDA PFDataL1,X
	STA PF1
	LDA PFDataL2,X
	STA PF2
	JMP ReEnter

DrawD
	LDA PFDataD0,X
	STA WSYNC
	STA PF0
	LDA PFDataD1,X
	STA PF1
	LDA PFDataD2,X
	STA PF2
	JMP ReEnter

DrawU
	LDA PFDataU0,X
	STA WSYNC
	STA PF0
	LDA PFDataU1,X
	STA PF1
	LDA PFDataU2,X
	STA PF2
	JMP ReEnter

OverScan
	LDX #30
KillLines
	 STA WSYNC
	 DEX
	 BNE KillLines
	RTS

CheckStick
	LDA  SWCHA	;Load joystick status
	LDY  #$FF
	ASL		;Check right joystick movement
	BCS  CheckLeft	;Nope. Check left joystick movement
	STY  Right	;Turn Right "on"
	RTS
CheckLeft
	ASL		;Check left joystick movement
	BCS  CheckDown	;Nope. Check down joystick movement
	STY  Left	;Turn Left "on"
	RTS
CheckDown
	ASL		;Check down joystick movement
	BCS  CheckUp	;Nope. Check up joystick movement
	STY  Down	;Turn Down "on"
	RTS
CheckUp
	ASL		;Check up joystick movement
	BCS  Done	;Nope. No movement occured.  All done!
	STY  Up		;Turn Down "on"
	RTS
Done
	RTS


	org $FF00 ; Playfield/Graphics data

PFData0
       .byte $00,$A0,$A0,$60,$A0,$60,$00,$00
PFData1
       .byte $00,$75,$45,$67,$45,$72,$00,$00
PFData2
       .byte $00,$46,$4A,$4A,$AA,$A6,$00,$00
PFDataR0
       .byte $00,$00,$A0,$A0,$60,$A0,$E0,$00
PFDataR1
       .byte $1C,$04,$5D,$55,$5D,$01,$41,$00
PFDataR2
       .byte $00,$00,$22,$52,$13,$38,$10,$00
PFDataL0
       .byte $00,$C0,$40,$40,$40,$40,$40,$00
PFDataL1
       .byte $00,$CE,$10,$1E,$12,$0C,$00,$00
PFDataL2
       .byte $00,$42,$22,$22,$27,$72,$26,$00
PFDataD0
       .byte $00,$60,$A0,$A0,$A0,$A0,$60,$00
PFDataD1
       .byte $00,$31,$49,$4A,$32,$00,$00,$00
PFDataD2
       .byte $00,$52,$52,$55,$35,$00,$00,$00
PFDataU0
       .byte $00,$00,$00,$00,$00,$00,$00,$00
PFDataU1
       .byte $00,$19,$25,$25,$25,$25,$25,$00
PFDataU2
       .byte $00,$00,$00,$03,$04,$04,$03,$00

	org $FFFC
	.word START
	.word START

	org $FF00

